Re: [Libreoffice-qa] ESC meeting minutes: 2021-01-14

2021-01-20 Thread Nicolas Christener
Hi Noel

On Thu, 2021-01-14 at 18:46 +0200, Noel Grandin wrote:
[...]
> I'm not deeply attached to SvStreamEOFException, I think,
> with extensive therapy and several glasses of decent Merlot, I can probably
> get over its removal.

I'm happy to ship some decent Merlot to you if this is a motivation :)

All the best,
Nicolas

-- 
born between rfc 812 and 813
gpg key: 0x5897DDEE05029923
3B06 ED04 A2DD 1863 0830  373E 5897 DDEE 0502 9923


___
List Name: Libreoffice-qa mailing list
Mail address: Libreoffice-qa@lists.freedesktop.org
Change settings: https://lists.freedesktop.org/mailman/listinfo/libreoffice-qa
Problems? http://www.libreoffice.org/get-help/mailing-lists/how-to-unsubscribe/
Posting guidelines + more: http://wiki.documentfoundation.org/Netiquette
List archive: http://lists.freedesktop.org/archives/libreoffice-qa/


Re: ESC meeting minutes: 2021-01-14

2021-01-15 Thread Nicolas Christener
Hi Noel

On Thu, 2021-01-14 at 18:46 +0200, Noel Grandin wrote:
[...]
> I'm not deeply attached to SvStreamEOFException, I think,
> with extensive therapy and several glasses of decent Merlot, I can probably
> get over its removal.

I'm happy to ship some decent Merlot to you if this is a motivation :)

All the best,
Nicolas

-- 
born between rfc 812 and 813
gpg key: 0x5897DDEE05029923
3B06 ED04 A2DD 1863 0830  373E 5897 DDEE 0502 9923


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: sw/source

2015-09-25 Thread Nicolas Christener
 sw/source/filter/ww8/ww8graf2.cxx |  160 +++---
 1 file changed, 81 insertions(+), 79 deletions(-)

New commits:
commit c70fc890b09f91cd4e12e212f1257518701f1505
Author: Nicolas Christener <n...@0x17.ch>
Date:   Fri Sep 25 11:37:35 2015 +0200

translate DE->EN, minor indentation fixes

Change-Id: Ie4672b41fcd67998187c5766dff8ee340b92e124
Reviewed-on: https://gerrit.libreoffice.org/18841
Tested-by: Jenkins <c...@libreoffice.org>
Reviewed-by: Caolán McNamara <caol...@redhat.com>
Tested-by: Caolán McNamara <caol...@redhat.com>

diff --git a/sw/source/filter/ww8/ww8graf2.cxx 
b/sw/source/filter/ww8/ww8graf2.cxx
index 91717f8..6af7d80 100644
--- a/sw/source/filter/ww8/ww8graf2.cxx
+++ b/sw/source/filter/ww8/ww8graf2.cxx
@@ -157,8 +157,8 @@ sal_uLong wwZOrderer::GetEscherObjectPos( sal_uLong nSpId,
 return nRet;
 }
 
-// InsertObj() fuegt das Objekt in die Sw-Page ein und merkt sich die Z-Pos in
-// einem VarArr
+// InsertObj() adds the object into the Sw-Page and memorize the Z-position
+// in a VarArr
 void wwZOrderer::InsertDrawingObject(SdrObject* pObj, short nWwHeight)
 {
 sal_uLong nPos = GetDrawingObjectPos(nWwHeight);
@@ -204,12 +204,14 @@ void wwZOrderer::InsertTextLayerObject(SdrObject* pObject)
 }
 }
 
-// Parallel zu dem Obj-Array im Dokument baue ich ein Array auf,
-// dass die Ww-Height ( -> Wer ueberdeckt wen ) beinhaltet.
-// Anhand dieses VARARR wird die Einfuegeposition ermittelt.
-// Der Offset bei Datei in bestehendes Dokument mit Grafiklayer einfuegen
-// muss der Aufrufer den Index um mnNoInitialObjects erhoeht werden, damit die
-// neuen Objekte am Ende landen ( Einfuegen ist dann schneller )
+/* Parallel to the Obj-array in the document I also build an array which
+ * contains the Ww-height (-> what covers what).
+ * Based on this VARARR the position where the insertion happens is
+ * determined.
+ * When inserting the offset in an existing document with a graphic layer the
+ * caller has to increment the index by mnNoInitialObjects, so that the new
+ * objects are added at the end (inserting is faster then)
+ */
 sal_uLong wwZOrderer::GetDrawingObjectPos(short nWwHeight)
 {
 myditer aIter = maDrawHeight.begin();
@@ -246,24 +248,24 @@ bool SwWW8ImplReader::GetPictGrafFromStream(Graphic& 
rGraphic, SvStream& rSrc)
 
 bool SwWW8ImplReader::ReadGrafFile(OUString& rFileName, Graphic*& rpGraphic,
 const WW8_PIC& rPic, SvStream* pSt, sal_uLong nFilePos, bool* pbInDoc)
-{  // Grafik in File schreiben
+{  // Write the graphic to the 
file
 *pbInDoc = true;   // default
 
 sal_uLong nPosFc = nFilePos + rPic.cbHeader;
 
 switch (rPic.MFP.mm)
 {
-case 94: // BMP-File ( nicht embeddet ) oder GIF
-case 99: // TIFF-File ( nicht embeddet )
+case 94: // BMP-file ( not embedded ) or GIF
+case 99: // TIFF-file ( not embedded )
 pSt->Seek(nPosFc);
-// Name als P-String einlesen
+// read name as P-string
 rFileName = read_uInt8_PascalString(*pSt, m_eStructCharSet);
 if (!rFileName.isEmpty())
 rFileName = URIHelper::SmartRel2Abs(
 INetURLObject(m_sBaseURL), rFileName,
 URIHelper::GetMaybeFileHdl());
-*pbInDoc = false;   // Datei anschliessend nicht loeschen
-return !rFileName.isEmpty();// Einlesen OK
+*pbInDoc = false;   // Don't delete the file afterwards
+return !rFileName.isEmpty();// read was successful
 }
 
 GDIMetaFile aWMF;
@@ -273,16 +275,16 @@ bool SwWW8ImplReader::ReadGrafFile(OUString& rFileName, 
Graphic*& rpGraphic,
 if (!bOk || pSt->GetError() || !aWMF.GetActionSize())
 return false;
 
-if (m_pWwFib->envr != 1) // !MAC als Creator
+if (m_pWwFib->envr != 1) // !MAC as creator
 {
 rpGraphic = new Graphic( aWMF );
 return true;
 }
 
-// MAC - Word als Creator
-// im WMF steht nur "Benutzen sie Word 6.0c" Mac-Pict steht dahinter
-// allerdings ohne die ersten 512 Bytes, bei einem MAC-PICT egal sind (
-// werden nicht ausgewertet )
+// MAC - word as creator
+// The WMF only says "Please use Word 6.0c" and Mac-Pict follows but 
without
+// the first 512 Bytes which are not relevant in a MAC-PICT (they are not
+// interpreted)
 bOk = false;
 long nData = rPic.lcb - ( pSt->Tell() - nPosFc );
 if (nData > 0)
@@ -291,7 +293,7 @@ bool SwWW8ImplReader::ReadGrafFile(OUString& rFileName, 
Graphic*& rpGraphic,
 if (!(bOk = SwWW8ImplReader::GetPictGrafFromStream(*rpGraphic, *pSt)))
 DELETEZ(rpGraphic);
 }
-return bOk; // Grafik drin
+return bOk; 

[Libreoffice-commits] core.git: sw/source

2015-09-25 Thread Nicolas Christener
 sw/source/filter/ww8/ww8par4.cxx |   82 ++-
 1 file changed, 38 insertions(+), 44 deletions(-)

New commits:
commit d1ffcc6f6b6b62a69a47dffe7efb3314fe8a13e7
Author: Nicolas Christener <n...@0x17.ch>
Date:   Fri Sep 25 20:27:19 2015 +0200

translate DE->EN

Change-Id: I59518e6cc8d497679f411a782c95291ae5bee0c6
Reviewed-on: https://gerrit.libreoffice.org/18876
Reviewed-by: Caolán McNamara <caol...@redhat.com>
Tested-by: Caolán McNamara <caol...@redhat.com>

diff --git a/sc/source/ui/dbgui/pfiltdlg.cxx b/sc/source/ui/dbgui/pfiltdlg.cxx
index 87de436..078fbfc 100644
--- a/sc/source/ui/dbgui/pfiltdlg.cxx
+++ b/sc/source/ui/dbgui/pfiltdlg.cxx
@@ -56,7 +56,7 @@ ScPivotFilterDlg::ScPivotFilterDlg(vcl::Window* pParent, 
const SfxItemSet& rArgS
 pOutItem( NULL ),
 pViewData   ( NULL ),
 pDoc( NULL ),
-nSrcTab ( nSourceTab ), // ist nicht im QueryParam
+nSrcTab ( nSourceTab ), // is not in QueryParam
 nFieldCount ( 0 )
 {
 get(m_pLbField1, "field1");
@@ -133,7 +133,7 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
 pViewData   = rQueryItem.GetViewData();
 pDoc= pViewData ? pViewData->GetDocument() : NULL;
 
-// fuer leichteren Zugriff:
+// for easier access:
 aFieldLbArr  [0] = m_pLbField1;
 aFieldLbArr  [1] = m_pLbField2;
 aFieldLbArr  [2] = m_pLbField3;
@@ -155,10 +155,7 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
 ScDBCollection* pDBColl = pDoc->GetDBCollection();
 OUString theDbName = OUString(STR_DB_LOCAL_NONAME);
 
-/*
- * Ueberpruefen, ob es sich bei dem uebergebenen
- * Bereich um einen Datenbankbereich handelt:
- */
+ // Check if the passed range is a database range
 
 if ( pDBColl )
 {
@@ -182,7 +179,7 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
 m_pFtDbArea->SetText( EMPTY_OUSTRING );
 }
 
-// Feldlisten einlesen und Eintraege selektieren:
+// Read the field lists and select the entries:
 
 FillFieldLists();
 
@@ -209,15 +206,15 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
 }
 else
 {
-aFieldLbArr[i]->SelectEntryPos( 0 ); // "keiner" selektieren
-aCondLbArr [i]->SelectEntryPos( 0 ); // "=" selektieren
+aFieldLbArr[i]->SelectEntryPos( 0 ); // "none" selected
+aCondLbArr [i]->SelectEntryPos( 0 ); // "=" selected
 UpdateValueList( static_cast(i) );
 aValueEdArr[i]->SetText( EMPTY_OUSTRING );
 }
 aValueEdArr[i]->SetModifyHdl( LINK( this, ScPivotFilterDlg, 
ValModifyHdl ) );
 }
 
-// Disable/Enable Logik:
+// disable/enable logic:
 
(m_pLbField1->GetSelectEntryPos() != 0)
 && (m_pLbField2->GetSelectEntryPos() != 0)
@@ -381,9 +378,9 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
 OUString aStrVal = aValueEdArr[i]->GetText();
 
 /*
- * Dialog liefert die ausgezeichneten Feldwerte "leer"/"nicht leer"
- * als Konstanten in nVal in Verbindung mit dem Schalter
- * bQueryByString auf FALSE.
+ * The dialog returns the specifc field values "empty"/"non empty"
+ * as constant in nVal in connection with the bQueryByString switch
+ * set to false
  */
 if ( aStrVal.equals(aStrEmpty) )
 {
@@ -416,7 +413,7 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
 : SC_AND;
 
 theParam.bInplace   = false;
-theParam.nDestTab   = 0;// Woher kommen diese Werte?
+theParam.nDestTab   = 0;// Where do those values come from?
 theParam.nDestCol   = 0;
 theParam.nDestRow   = 0;
 
@@ -434,11 +431,10 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
 
 IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
 {
+
 /*
- * Behandlung der Enable/Disable-Logik,
- * abhaengig davon, welche ListBox angefasst wurde:
+ * Handling the enable/disable logic based on which ListBox was touched:
  */
-
 if (pLb == m_pLbConnect1)
 {
 if ( !m_pLbField2->IsEnabled() )
@@ -525,9 +521,9 @@ IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
 
 IMPL_LINK_TYPED( ScPivotFilterDlg, CheckBoxHdl, Button*, pBox, void )
 {
-//  bei Gross-/Kleinschreibung die Werte-Listen aktualisieren
+// update the value lists when dealing with uppercase/lowercase
 
-if (pBox == m_pBtnCase)// Wertlisten
+if (pBox == m_pBtnCase)// value lists
 {

[Libreoffice-commits] core.git: sw/source

2015-09-24 Thread Nicolas Christener
 sw/source/core/table/swtable.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 5e1944c70b6423b47e1490df7920217e83d662c9
Author: Nicolas Christener <n...@0x17.ch>
Date:   Thu Sep 24 17:10:32 2015 +0200

translate DE->EN, fix typo

Change-Id: I67f0161ab0ed1d44df1b8dbcfd1d200f5e9bbe2f
Reviewed-on: https://gerrit.libreoffice.org/18829
Tested-by: Jenkins <c...@libreoffice.org>
Reviewed-by: Adolfo Jayme Barrientos <fit...@ubuntu.com>

diff --git a/sw/source/core/table/swtable.cxx b/sw/source/core/table/swtable.cxx
index 93abe09..ca75280 100644
--- a/sw/source/core/table/swtable.cxx
+++ b/sw/source/core/table/swtable.cxx
@@ -888,7 +888,7 @@ void SwTable::SetTabCols( const SwTabCols , const 
SwTabCols ,
 
 Parm aParm( rNew, rOld );
 
-OSL_ENSURE( rOld.Count() == rNew.Count(), "Columnanzahl veraendert.");
+OSL_ENSURE( rOld.Count() == rNew.Count(), "Number of columns changed.");
 
 // Convert the edges. We need to adjust the size of the table and some 
boxes.
 // For the size adjustment, we must not make use of the Modify, since 
that'd
@@ -2239,7 +2239,7 @@ void SwTableBoxFormat::Modify( const SfxPoolItem* pOld, 
const SfxPoolItem* pNew
 SwTableBox* pBox = aIter.First();
 if( pBox )
 {
-OSL_ENSURE( !aIter.Next(), "zeor or more than one box at 
format" );
+OSL_ENSURE( !aIter.Next(), "zero or more than one box at 
format" );
 
 sal_uLong nNewFormat;
 if( pNewFormat )
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Changes to 'refs/changes/76/5276/1'

2014-09-29 Thread Nicolas Christener

___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Changes to 'refs/changes/76/5276/2'

2014-09-29 Thread Nicolas Christener

___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2013-08-05 Thread Nicolas Christener
 sw/source/core/layout/trvlfrm.cxx |  481 +-
 1 file changed, 216 insertions(+), 265 deletions(-)

New commits:
commit 7ee94597030e986ece350036093d1e4a213dcddc
Author: Nicolas Christener n...@0x17.ch
Date:   Sun Aug 4 17:23:08 2013 +0200

fdo#39468 Comment translation GER-ENG in sw/source/core/layout

Change-Id: Ia4bdd0fe4f515ae772685b10da519c4b3cf727c8
Reviewed-on: https://gerrit.libreoffice.org/5276
Reviewed-by: Miklos Vajna vmik...@suse.cz
Tested-by: Miklos Vajna vmik...@suse.cz

diff --git a/sw/source/core/layout/trvlfrm.cxx 
b/sw/source/core/layout/trvlfrm.cxx
index e431850..843f39a 100644
--- a/sw/source/core/layout/trvlfrm.cxx
+++ b/sw/source/core/layout/trvlfrm.cxx
@@ -114,19 +114,16 @@ namespace {
 }
 
 
-//Fuer SwFlyFrm::GetCrsrOfst
+//For SwFlyFrm::GetCrsrOfst
 class SwCrsrOszControl
 {
 public:
-// damit schon der Compiler die Klasse initialisieren kann, keinen
-// DTOR und member als publics:
+// So the compiler can initialize the class already. No DTOR and member
+// as public members
 const SwFlyFrm *pEntry;
 const SwFlyFrm *pStk1;
 const SwFlyFrm *pStk2;
 
-//public:
-//SwCrsrOszControl() : pStk1( 0 ), pStk2( 0 ) {}; // ; - 
-
 bool ChkOsz( const SwFlyFrm *pFly )
 {
 bool bRet = true;
@@ -156,8 +153,8 @@ static SwCrsrOszControl aOszCtrl = { 0, 0, 0 };
 |*
 |*  SwLayoutFrm::GetCrsrOfst()
 |*
-|*  Beschreibung:   Sucht denjenigen CntntFrm, innerhalb dessen
-|*  PrtArea der Point liegt.
+|*  Description:Searches the CntntFrm owning the PrtArea
+|*  containing the point.
 |*
 |*/
 sal_Bool SwLayoutFrm::GetCrsrOfst( SwPosition *pPos, Point rPoint,
@@ -190,8 +187,7 @@ sal_Bool SwLayoutFrm::GetCrsrOfst( SwPosition *pPos, Point 
rPoint,
 |*
 |*  SwPageFrm::GetCrsrOfst()
 |*
-|*  Beschreibung:   Sucht die Seite, innerhalb der der gesuchte Point
-|*  liegt.
+|*  Description:Searches the page containing the searched point.
 |*
 |*/
 
@@ -212,9 +208,9 @@ sal_Bool SwPageFrm::GetCrsrOfst( SwPosition *pPos, Point 
rPoint,
 
 sal_Bool bTextRet, bBackRet = sal_False;
 
-//Koennte ein Freifliegender gemeint sein?
-//Wenn sein Inhalt geschuetzt werden soll, so ist nix mit Crsr
-//hineinsetzen, dadurch sollten alle Aenderungen unmoeglich sein.
+//Could it be a free flying one?
+//If his content should be protected, we can't set the Crsr in it, thus
+//all changes should be impossible.
 if ( GetSortedObjs() )
 {
 bRet = lcl_GetCrsrOfst_Objects( this, false, pPos, rPoint, pCMS );
@@ -225,9 +221,9 @@ sal_Bool SwPageFrm::GetCrsrOfst( SwPosition *pPos, Point 
rPoint,
 SwPosition aBackPos( *pPos );
 SwPosition aTextPos( *pPos );
 
-//Wenn kein Cntnt unterhalb der Seite 'antwortet', so korrigieren
-//wir den StartPoint und fangen nochmal eine Seite vor der
-//aktuellen an. Mit Flys ist es dann allerdings vorbei.
+//We fix the StartPoint if no Cntnt below the page 'answers' and then
+//start all over again one page before the current one.
+//However we cant use Flys in such a case.
 if ( SwLayoutFrm::GetCrsrOfst( aTextPos, aPoint, pCMS ) )
 {
 bTextRet = sal_True;
@@ -403,9 +399,8 @@ bool SwRootFrm::FillSelection( SwSelectionList aSelList, 
const SwRect rRect) c
 |*
 |*  SwRootFrm::GetCrsrOfst()
 |*
-|*  Beschreibung:   Reicht Primaer den Aufruf an die erste Seite weiter.
-|*  Wenn der 'reingereichte Point veraendert wird,
-|*  so wird sal_False zurueckgegeben.
+|*  Description:Primary passes the call to the first page.
+|*  If the passed Point gets changed we return sal_False.
 |*
 |*/
 sal_Bool SwRootFrm::GetCrsrOfst( SwPosition *pPos, Point rPoint,
@@ -413,7 +408,7 @@ sal_Bool SwRootFrm::GetCrsrOfst( SwPosition *pPos, Point 
rPoint,
 {
 sal_Bool bOldAction = IsCallbackActionEnabled();
 ((SwRootFrm*)this)-SetCallbackActionEnabled( sal_False );
-OSL_ENSURE( (Lower()  Lower()-IsPageFrm()), Keinen PageFrm gefunden. 
);
+OSL_ENSURE( (Lower()  Lower()-IsPageFrm()), No PageFrm found. );
 if( pCMS  pCMS-pFill )
 ((SwCrsrMoveState*)pCMS)-bFillRet = sal_False;
 Point aOldPoint = rPoint;
@@ -453,10 +448,10 @@ sal_Bool SwRootFrm::GetCrsrOfst( SwPosition *pPos, Point 
rPoint,
 |*
 |*  SwCellFrm::GetCrsrOfst()
 |*
-|*  BeschreibungWenn es sich um eine Cntnt-tragende Cell handelt wird
-|*  der Crsr notfalls mit Gewalt in einen der CntntFrms
-|*  gesetzt.
-|*  In geschuetzte Zellen gibt es hier keinen Eingang

[PATCH] rename WEIT_WECH to FAR_AWAY

2012-03-23 Thread Nicolas Christener
Hi all

I stumbled over #define WEIT_WECH [...] in
sw/source/core/inc/frmtool.hxx while translating some German comments
for Cedric.

I asked on IRC if I should translate this to FAR_AWAY and got a go
there. Attached is a patch which should do the trick - review much
appreciated.

I did a make afterwards which went through, however I couldn't run
make check because I ran into this problem here:
http://lists.freedesktop.org/archives/libreoffice/2012-January/024161.html
Some more information including my configure options:
http://dpaste.com/hold/719777/
Any idea how I can fix this?

thanks, nicolas
From c5ef2c22f26f058bdbad12bc5682ce0adee12709 Mon Sep 17 00:00:00 2001
From: Nicolas Christener nicolas.christe...@adfinis-sygroup.ch
Date: Wed, 21 Mar 2012 23:26:30 +0100
Subject: [PATCH] Rename WEIT_WECH to FAR_AWAY

---
 sw/source/core/inc/frmtool.hxx |2 +-
 sw/source/core/layout/calcmove.cxx |4 ++--
 sw/source/core/layout/fly.cxx  |   10 +-
 sw/source/core/layout/frmtool.cxx  |   16 
 sw/source/core/layout/laycache.cxx |4 ++--
 sw/source/core/layout/pagechg.cxx  |4 ++--
 sw/source/core/layout/tabfrm.cxx   |6 +++---
 sw/source/core/text/txtfly.cxx |2 +-
 8 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/sw/source/core/inc/frmtool.hxx b/sw/source/core/inc/frmtool.hxx
index ba1b0f4..e31d8b9 100644
--- a/sw/source/core/inc/frmtool.hxx
+++ b/sw/source/core/inc/frmtool.hxx
@@ -56,7 +56,7 @@ struct SwFindRowSpanCacheObj;
 #define MA_FASTCALL
 #endif
 
-#define WEIT_WECH   LONG_MAX - 2//Initale Position der Flys.
+#define FAR_AWAY   LONG_MAX - 2//Initale Position der Flys.
 #define BROWSE_HEIGHT   56700L * 10L   //10 Meter
 
 #define GRFNUM_NO 0
diff --git a/sw/source/core/layout/calcmove.cxx b/sw/source/core/layout/calcmove.cxx
index 33e6722..eeccc20 100644
--- a/sw/source/core/layout/calcmove.cxx
+++ b/sw/source/core/layout/calcmove.cxx
@@ -669,7 +669,7 @@ void lcl_CheckObjects( SwSortedObjs* pSortedObjs, SwFrm* pFrm, long rBot )
 if ( pObj-ISA(SwFlyFrm) )
 {
 SwFlyFrm *pFly = static_castSwFlyFrm*(pObj);
-if( pFly-Frm().Top() != WEIT_WECH 
+if( pFly-Frm().Top() != FAR_AWAY 
 ( pFrm-IsPageFrm() ? pFly-IsFlyLayFrm() :
   ( pFly-IsFlyAtCntFrm() 
 ( pFrm-IsBodyFrm() ? pFly-GetAnchorFrm()-IsInDocBody() :
@@ -1012,7 +1012,7 @@ sal_Bool SwCntntFrm::MakePrtArea( const SwBorderAttrs rAttrs )
 SwAnchoredObject* pObj = (*GetDrawObjs())[i];
 const SwFrmFmt rFmt = pObj-GetFrmFmt();
 const sal_Bool bFly = pObj-ISA(SwFlyFrm);
-if ((bFly  (WEIT_WECH == pObj-GetObjRect().Width()))
+if ((bFly  (FAR_AWAY == pObj-GetObjRect().Width()))
 || rFmt.GetFrmSize().GetWidthPercent())
 {
 continue;
diff --git a/sw/source/core/layout/fly.cxx b/sw/source/core/layout/fly.cxx
index b6e7b1f..cc7c170 100644
--- a/sw/source/core/layout/fly.cxx
+++ b/sw/source/core/layout/fly.cxx
@@ -192,7 +192,7 @@ SwFlyFrm::SwFlyFrm( SwFlyFrmFmt *pFmt, SwFrm* pSib, SwFrm *pAnch ) :
 
 //Und erstmal in den Wald stellen die Kiste, damit bei neuen Dokument nicht
 //unnoetig viel formatiert wird.
-Frm().Pos().X() = Frm().Pos().Y() = WEIT_WECH;
+Frm().Pos().X() = Frm().Pos().Y() = FAR_AWAY;
 }
 
 // OD 2004-01-19 #110582#
@@ -1339,7 +1339,7 @@ void SwFlyFrm::Format( const SwBorderAttrs *pAttrs )
 
 if ( !bValidSize )
 {
-if ( Frm().Top() == WEIT_WECH  Frm().Left() == WEIT_WECH )
+if ( Frm().Top() == FAR_AWAY  Frm().Left() == FAR_AWAY )
 {
 //Sicherheitsschaltung wegnehmen (siehe SwFrm::CTor)
 Frm().Pos().X() = Frm().Pos().Y() = 0;
@@ -1414,7 +1414,7 @@ void SwFlyFrm::Format( const SwBorderAttrs *pAttrs )
 // OD 06.11.2003 #i22305# - consider
 // only Writer fly frames, which follow the text flow.
 if ( pFly-IsFlyLayFrm() 
- pFly-Frm().Top() != WEIT_WECH 
+ pFly-Frm().Top() != FAR_AWAY 
  pFly-GetFmt()-GetFollowTextFlow().GetValue() )
 {
 SwTwips nDist = -(pFly-Frm().*fnRect-
@@ -2149,7 +2149,7 @@ void SwFrm::AppendFly( SwFlyFrm *pNew )
 SwPageFrm *pPage = FindPageFrm();
 if ( pPage )
 {
-if ( pNew-IsFlyAtCntFrm()  pNew-Frm().Top() == WEIT_WECH )
+if ( pNew-IsFlyAtCntFrm()  pNew-Frm().Top() == FAR_AWAY )
 {
 //Versuch die Seitenformatierung von neuen Dokumenten etwas
 //guenstiger zu gestalten.
@@ -2424,7 +2424,7 @@ void SwLayoutFrm::NotifyLowerObjs( const bool _bUnlockPosOfObjs )
 {
 SwFlyFrm

[PATCH] translate german comments

2012-03-12 Thread Nicolas Christener
Hi :)

Attached is one more German-English comment translation patch.

Review much appreciated.

Kind regards
nicolas
From a67c8fb99d0006664b1583bc11258a147ce90f0b Mon Sep 17 00:00:00 2001
From: Nicolas Christener nicolas.christe...@adfinis-sygroup.ch
Date: Thu, 8 Mar 2012 20:37:40 +0100
Subject: [PATCH] translate german comments

---
 sw/source/core/layout/tabfrm.cxx |  322 ++
 1 files changed, 153 insertions(+), 169 deletions(-)

diff --git a/sw/source/core/layout/tabfrm.cxx b/sw/source/core/layout/tabfrm.cxx
index 95eceb8..40c949f 100644
--- a/sw/source/core/layout/tabfrm.cxx
+++ b/sw/source/core/layout/tabfrm.cxx
@@ -96,10 +96,10 @@ SwTabFrm::SwTabFrm( SwTable rTab, SwFrm* pSib ):
 // #i26945#
 bConsiderObjsForMinCellHeight = sal_True;
 bObjsDoesFit = sal_True;
-bFixSize = sal_False; //Nicht nochmal auf die Importfilter hereinfallen.
+bFixSize = sal_False; //Don't fall for import filter again.
 nType = FRMC_TAB;
 
-//Gleich die Zeilen erzeugen und einfuegen.
+//Create the lines and insert them.
 const SwTableLines rLines = rTab.GetTabLines();
 SwFrm *pTmpPrev = 0;
 for ( sal_uInt16 i = 0; i  rLines.Count(); ++i )
@@ -127,7 +127,7 @@ SwTabFrm::SwTabFrm( SwTabFrm rTab ) :
 // #i26945#
 bConsiderObjsForMinCellHeight = sal_True;
 bObjsDoesFit = sal_True;
-bFixSize = sal_False; //Nicht nochmal auf die Importfilter hereinfallen.
+bFixSize = sal_False; //Don't fall for import filter again.
 nType = FRMC_TAB;
 
 SetFollow( rTab.GetFollow() );
@@ -180,7 +180,7 @@ void SwTabFrm::JoinAndDelFollows()
 |*/
 void SwTabFrm::RegistFlys()
 {
-OSL_ENSURE( Lower()  Lower()-IsRowFrm(), Keine Zeilen. );
+OSL_ENSURE( Lower()  Lower()-IsRowFrm(), No rows. );
 
 SwPageFrm *pPage = FindPageFrm();
 if ( pPage )
@@ -432,7 +432,7 @@ void lcl_MoveRowContent( SwRowFrm rSourceLine, SwRowFrm rDestLine )
 while ( pTmpDestRow-GetNext() )
 pTmpDestRow = (SwRowFrm*)pTmpDestRow-GetNext();
 
-OSL_ENSURE( pTmpDestRow-GetFollowRow() == pTmpSourceRow, Knoten in der Tabelle );
+OSL_ENSURE( pTmpDestRow-GetFollowRow() == pTmpSourceRow, Table contains node );
 
 lcl_MoveRowContent( *pTmpSourceRow, *pTmpDestRow );
 pTmpDestRow-SetFollowRow( pTmpSourceRow-GetFollowRow() );
@@ -996,9 +996,9 @@ bool SwTabFrm::Split( const SwTwips nCutPos, bool bTryToSplit, bool bTableRowKee
 lcl_InnerCalcLayout( this-Lower(), LONG_MAX, true );
 }
 
-//Um die Positionen der Zellen mit der CutPos zu vergleichen muessen sie
-//ausgehend von der Tabelle nacheinander berechnet werden. Sie koennen
-//wg. Positionsaenderungen der Tabelle durchaus ungueltig sein.
+//In order to be able to compare the positions of the cells whit CutPos,
+//they have to be calculated consecutively starting from the table.
+//They can definitely be invalid because of position changes of the table.
 SwRowFrm *pRow = static_castSwRowFrm*(Lower());
 if( !pRow )
 return bRet;
@@ -1268,9 +1268,9 @@ bool SwTabFrm::Split( const SwTwips nCutPos, bool bTryToSplit, bool bTableRowKee
 
 SwTwips nRet = 0;
 
-//Optimierung beim neuen Follow braucht's kein Paste und dann kann
-//das Optimierte Insert verwendet werden (nur dann treten gluecklicher weise
-//auch groessere Mengen von Rows auf).
+//Optimization: There is no paste needed for the new Follow and the
+//optimized insert can be used (big amounts of rows luckily only occurs in
+//such situations).
 if ( bNewFollow )
 {
 SwFrm* pNxt = 0;
@@ -1344,15 +1344,15 @@ bool SwTabFrm::Join()
 if ( !pFoll-IsJoinLocked() )
 {
 SWRECTFN( this )
-pFoll-Cut();   //Erst ausschneiden um unuetze Benachrichtigungen zu
-//minimieren.
+pFoll-Cut();   //Cut out first to avoid unnecessary notifications.
 
 SwFrm *pRow = pFoll-GetFirstNonHeadlineRow(),
   *pNxt;
 
 SwFrm* pPrv = GetLastLower();
 
-SwTwips nHeight = 0;//Gesamthoehe der eingefuegten Zeilen als Return.
+SwTwips nHeight = 0;//Total height of the inserted rows as return value.
+
 while ( pRow )
 {
 pNxt = pRow-GetNext();
@@ -1818,14 +1818,13 @@ void SwTabFrm::MakeAll()
 
 PROTOCOL_ENTER( this, PROT_MAKEALL, 0, 0 )
 
-LockJoin(); //Ich lass mich nicht unterwegs vernichten.
-SwLayNotify aNotify( this );//uebernimmt im DTor die Benachrichtigung
+LockJoin(); //I don't want to be destroyed on the way.
+SwLayNotify aNotify( this );//does the notification in the DTor
 // If pos is invalid, we have to call a SetInvaKeep at aNotify.
 // Otherwise the keep atribute would not work in front of a table.
 const sal_Bool

Re: [PATCH] Translate German comments - final patch

2012-02-15 Thread Nicolas Christener
Hi

On Wed, 2012-02-15 at 13:56 +, Michael Meeks wrote:
[...]
  So, any developer wishes on what to translate next?
 
   Cedric was giving a personal plea for sw/source/core/layout/ which he
 wrestles with daily, is non-obvious code, and packed with impenetrable
 German ;-) ~2700 detected lines in there ..

I'm already working on this and will provide patches in a few days :)

kind regards


signature.asc
Description: This is a digitally signed message part
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [PATCH] Translate German comments - final patch

2012-02-15 Thread Nicolas Christener
Hi

On Wed, 2012-02-15 at 13:56 +, Michael Meeks wrote:
[...]
  So, any developer wishes on what to translate next?
 
   Cedric was giving a personal plea for sw/source/core/layout/ which he
 wrestles with daily, is non-obvious code, and packed with impenetrable
 German ;-) ~2700 detected lines in there ..

I'm already working on this and will provide patches in a few days :)

kind regards
nicolas

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice
diff --git a/sw/source/filter/ww8/ww8par4.cxx b/sw/source/filter/ww8/ww8par4.cxx
index 1aeaacb..0a5d6be 100644
--- a/sw/source/filter/ww8/ww8par4.cxx
+++ b/sw/source/filter/ww8/ww8par4.cxx
@@ -69,17 +69,17 @@ using namespace ::com::sun::star;
 
 static bool SwWw8ReadScaling(long& rX, long& rY, tools::SvRef& 
rSrc1)
 {
-// Skalierungsfaktoren holen:
-//  Informationen in PIC-Stream ( durch ausprobieren )
+// Getting the scaling factor:
+//  Information in the PIC-stream (by trying out)
 //  0x0  (l)cb
 //  0x08 .. 0x0a Flags ??
 //  0x08 Inh: 1 / 0
 //  0x09 Inh: 0,8,0x18
 //  0x0a Inh: immer 8, MAP_ANISOTROPIC ???
 //  0x0b Inh: immer 0
 //  0x0c, 0x10 Originalgroesse x,y in 1/100 mm
 //  0x14, 0x16 Originalgroesse x,y in tw
 //  0x2c, 0x30 Skalierung x,y in Promille
 //  0x34, 0x38, 0x3c, 0x40 Crop Left, Top, Right, Bot in tw
 
 tools::SvRef xSrc3 = rSrc1->OpenSotStream( 
OUString("\3PIC"),
@@ -113,7 +113,7 @@ static bool SwWw8ReadScaling(long& rX, long& rY, 
tools::SvRef& rSrc1
 rY = nOrgHeight - nCropTop  - nCropBottom;
 if (10 > nScaleX || 65536 < nScaleX || 10 > nScaleY || 65536 < nScaleY)
 {
-OSL_ENSURE( !pS, "+OLE-Scalinginformation in PIC-Stream wrong" );
+OSL_ENSURE( !pS, "+OLE-scaling information in PIC-stream wrong" );
 return false;
 }
 else
@@ -132,7 +132,7 @@ static bool SwWw6ReadMetaStream(GDIMetaFile& rWMF, OLE_MFP* 
pMfp,
 SotStorageStream* pSt = xSrc2;
 pSt->SetEndian( SvStreamEndian::LITTLE );
 sal_uLong nRead = pSt->Read( pMfp, sizeof(*pMfp ) );
-// Mini-Placable-Header lesen
+// read mini-placable-header
 if (nRead != sizeof(*pMfp))
 return false;
 
@@ -144,30 +144,29 @@ static bool SwWw6ReadMetaStream(GDIMetaFile& rWMF, 
OLE_MFP* pMfp,
 
 if( pMfp->mm == 94 || pMfp->mm == 99 )
 {
-OSL_ENSURE( !pSt, "+OLE: Falscher Metafile-Typ" );
+OSL_ENSURE( !pSt, "+OLE: wrong metafile type" );
 return false;
 }
 if( pMfp->mm != 8 )
 {
-OSL_ENSURE( !pSt, "+OLE: Falscher Metafile-Typ ( nicht Anisotropic )" 
);
+OSL_ENSURE( !pSt, "+OLE: wrong mMetafile type (not anisotropic)" );
 }
 if( !pMfp->xExt || !pMfp->yExt )
 {
-OSL_ENSURE( !pSt, "+OLE: Groesse von 0 ???" );
+OSL_ENSURE( !pSt, "+OLE: size of 0?" );
 return false;
 }
-bool bOk = ReadWindowMetafile( *pSt, rWMF, NULL );   // WMF lesen
-// *pSt >> aWMF  geht nicht ohne placable Header
+bool bOk = ReadWindowMetafile( *pSt, rWMF, NULL );   // read WMF
+// *pSt >> aWMF  doesn't work without the placable header
 if (!bOk || pSt->GetError() || rWMF.GetActionSize() == 0)
 {
-OSL_ENSURE( !pSt, "+OLE: Konnte Metafile nicht lesen" );
+OSL_ENSURE( !pSt, "+OLE: could not read the metafile" );
 return false;
 }
 
 rWMF.SetPrefMapMode( MapMode( MAP_100TH_MM ) );
 
-// MetaFile auf neue Groesse skalieren und
-// neue Groesse am MetaFile setzen
+// Scale MetaFile to new size and save new size to MetaFile
 SizeaOldSiz( rWMF.GetPrefSize() );
 SizeaNewSiz( pMfp->xExt, pMfp->yExt );
 FractionaFracX( aNewSiz.Width(), aOldSiz.Width() );
@@ -181,19 +180,19 @@ static bool SwWw6ReadMetaStream(GDIMetaFile& rWMF, 
OLE_MFP* pMfp,
 
 static bool SwWw6ReadMacPICTStream(Graphic& rGraph, tools::SvRef& 
rSrc1)
 {
-// 03-META-Stream nicht da. Vielleicht ein 03-PICT ?
+// 03-META-stream does not exist. Maybe a 03-PICT?
 tools::SvRef xSrc4 = 
rSrc1->OpenSotStream(OUString("\3PICT"));
 SotStorageStream* pStp = xSrc4;
 pStp->SetEndian( SvStreamEndian::LITTLE );
-sal_uInt8 aTestA[10];// Ist der 01Ole-Stream ueberhaup
@@ -69,17 +69,17 @@ using namespace ::com::sun::star;
 //  0x0  (l)cb
 //  0x08 .. 0x0a Flags ??
-//  0x08 Inh: 1 / 0
-//  0x09 Inh: 0,8,0x18
-//  0x0a Inh: immer 8, MAP_ANISOTROPIC ???
-//  0x0b Inh: immer 0
-//  0x0c, 0x10 Originalgroesse x,y in 1/100 mm
-//  0x14, 0x16 Originalgroesse x,y in tw
-//  0x2c, 0x30 Skalierung x,y in Promille
+//  0x08 contains: 1 / 0
+//  0x09 contains: 0,8,0x18
+//  0x0a contains: always 8, MAP_ANISOTROPIC ???
+//  0x0b contains: always 0
+//  0x0c, 0x10 original size x,y in 1/100 mm
+//  0x14, 0x16 original size x,y in tw
+//  0x2c, 0x30 scaling x,y in per thousand
 //  0x34, 0x38, 0x3c, 0x40 Crop Left, Top, Right, Bot in tw
 

[Libreoffice-commits] core.git: sc/source

2015-09-25 Thread Nicolas Christener
 sc/source/ui/dbgui/pfiltdlg.cxx |   38 +-
 1 file changed, 17 insertions(+), 21 deletions(-)

New commits:
commit ec45130e108e229e6b1ad8e3293afbb4073630fa
Author: Nicolas Christener <n...@0x17.ch>
Date:   Thu Sep 24 22:53:27 2015 +0200

translate DE->EN

Change-Id: Ic0afa7dc008d1c36b68f37a915f575b21e1548da
Reviewed-on: https://gerrit.libreoffice.org/18840
Tested-by: Jenkins <c...@libreoffice.org>
Reviewed-by: Caolán McNamara <caol...@redhat.com>
Tested-by: Caolán McNamara <caol...@redhat.com>
